local HideBlizzard = LibStub("AceAddon-3.0"):GetAddon("HideBlizzard")
assert(HideBlizzard, "Options::HideBlizzard does not exist")

local type, pairs, optionFrame = type, pairs, {}
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")

local get, set
do
	function get(info)
		local key = info[#info] 
		return HideBlizzard.db.profile[key]
	end
	
	function set(info, value)
		local key = info[#info]
		HideBlizzard.db.profile[key] = value
		HideBlizzard:UpdateView()
	end
end

local options, moduleOptions = nil, {}
local function generalOptions()
	if not options then
		options = {
			name = "HideBlizzard",
			type = "group",
			args = {
				HideBlizzardOptions = {
					order = 1,
					type = "group",
					name = "HideBlizzard",
					get = get,
					set = set,
					args = {
						intro = {
						type = "description",
						order = 2,
						name = "Useful Commands",
						},
						reset = {
							type = "execute",
							order = 3,
							name = "reset",
							desc = "reset settings to defaults",
							width = "full",
							confirm = true,
							func = function()
								wipe(HideBlizzardDB)
								HideBlizzard:Print("Database reset, will take effect when you next login")
							end,
						},
						changelog = {
							type = "execute",
							order = 4,
							name = "changelog",
							desc = "view the latest changes",
							width = "full",
							func = function() HideBlizzard:ShowChangelog() end,
						},
						help = {
							type = "execute",
							order = 5,
							name = "help",
							desc = "view the help window",
							width = "full",
							func = function() HideBlizzard:ShowHelp() end,
						},
					},
				},
			},
		}
		for k,v in pairs(moduleOptions) do
			options.args[k] = (type(v) == "function") and v() or v
		end
	end
	return options
end

function HideBlizzard:RegisterOptions()
	self.optionFrame = {}

	AceConfigRegistry:RegisterOptionsTable("HideBlizzard", generalOptions)
	self.optionFrame.HideBlizzard = AceConfigDialog:AddToBlizOptions("HideBlizzard", nil, nil, "HideBlizzardOptions")
	self:RegisterModuleOptions("Profiles", AceDBOptions:GetOptionsTable(self.db), "Profiles")
end

function HideBlizzard:RegisterModuleOptions(name, optionTbl, displayName)
	moduleOptions[name] = optionTbl
	self.optionFrame[name] = AceConfigDialog:AddToBlizOptions("HideBlizzard", displayName, "HideBlizzard", name)
end