--HideBlizzard_Frames = {"PetActionBarFrame", "PetCastingBarFrame", "PetFrameHappiness", "PetFrame"}
local HideBlizzard = LibStub("AceAddon-3.0"):GetAddon("HideBlizzard")
assert(HideBlizzard, "Modules/Pets::HideBlizzard does not exist")

local MODNAME = "Pet"
local Pet = HideBlizzard:NewModule(MODNAME)
local Utils = HideBlizzard.Utils

local db
local defaults = {
	profile = {
		["petactionbar"] = nil,
		["petcastbar"] = nil,
		["pethappyframe"] = nil,
		["petunitframe"] = nil,
	},
}

local get, set
do
	local mod = Pet
	function get(info)
		local key = info[#info]
		return db[key]
	end

	function set(info, value)
		local key = info[#info]
		db[key] = value
		mod:UpdateView()
	end
end

local options = nil
local function moduleOptions()
	if not options then
		options = {
			type = "group",
			name = MODNAME,
			arg = MODNAME,
			get = get,
			set = set,
			args = {
				enabled = {
					type = "toggle",
					order = 1,
					name = "|cff00ff66Enable "..MODNAME.."|r",
					descStyle = "inline",
					desc = "Pet module hides pet related frames",
					width = "full",
					get = function() return HideBlizzard:GetModuleEnabled(MODNAME) end,
					set = function(info, value) HideBlizzard:SetModuleEnabled(MODNAME, value) end,
				},
				petactionbar = {
					type = "toggle",
					order = 2,
					name = "Pet Action Bar",
					desc = "Hides the pet action bar",
--					width = "full",
					disabled = function() return not Pet:IsEnabled() end,
				},
				petcastbar = {
					type = "toggle",
					order = 3,
					name = "Pet Cast Bar",
					desc = "Hides the pet casting bar",
--					width = "full",
					disabled = function() return not Pet:IsEnabled() end,
				},
				pethappyframe = {
					type = "toggle",
					order = 4,
					name = "Pet Happiness Frame",
					desc = "Hides the pet happiness frame",
--					width = "full",
					disabled = function() return not Pet:IsEnabled() or db.petunitframe end,
				},
				petunitframe = {
					type = "toggle",
					order = 5,
					name = "Pet Unit Frame",
					desc = "Hides the pet unit frame",
--					width = "full",
					disabled = function() return not Pet:IsEnabled() end,
				},
				reset = {
					type = "execute",
					order = 6,
					name = "reset module",
					desc = "use this if you're having trouble",
					width = "full",
					confirm = true,
					func = function() Utils:ModuleReset(MODNAME) end,
					disabled = function() return not Pet:IsEnabled() end,
				},
			},
		}
	end
	return options
end

function Pet:OnInitialize()
	self:SetEnabledState(HideBlizzard:GetModuleEnabled(MODNAME))
	self.db = HideBlizzard.db:RegisterNamespace(MODNAME, defaults)
	db = self.db.profile

	HideBlizzard:RegisterModuleOptions(MODNAME, moduleOptions, "Pet")
end

function Pet:OnEnable()
	self:UpdateView()
end

function Pet:OnDisable()
	self:UpdateView()
end

function Pet:UpdateView()
	db = self.db.profile

	if db.petactionbar == true then
		PetActionBarFrame:UnregisterAllEvents()
		PetActionBarFrame.Show = function() end
		PetActionBarFrame:Hide()
	else
		if UnitExists("pet") then
			PetActionBarFrame.Show = nil
			PetActionBarFrame:Show()
		end
		PetActionBarFrame:RegisterEvent("PLAYER_CONTROL_LOST")
		PetActionBarFrame:RegisterEvent("PLAYER_CONTROL_GAINED")
		PetActionBarFrame:RegisterEvent("PLAYER_FARSIGHT_FOCUS_CHANGED")
		PetActionBarFrame:RegisterEvent("UNIT_PET")
		PetActionBarFrame:RegisterEvent("UNIT_FLAGS")
		PetActionBarFrame:RegisterEvent("UNIT_AURA")
		PetActionBarFrame:RegisterEvent("PET_BAR_UPDATE")
		PetActionBarFrame:RegisterEvent("PET_BAR_UPDATE_COOLDOWN")
		PetActionBarFrame:RegisterEvent("PET_BAR_SHOWGRID")
		PetActionBarFrame:RegisterEvent("PET_BAR_HIDEGRID")
		PetActionBarFrame:RegisterEvent("PET_BAR_HIDE")
	end

	if db.petcastbar == true then
		PetCastingBarFrame:UnregisterAllEvents()
		PetCastingBarFrame:Hide()
	else
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_START")
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_STOP")
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_FAILED")
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_INTERRUPTED")
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_DELAYED")
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_CHANNEL_START")
		PetCastingBarFrame:RegisterEvent("UNIT_SPELLCAST_CHANNEL_UPDATE")
		PetCastingBarFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
		PetCastingBarFrame:RegisterEvent("UNIT_PET")
	end

	if db.pethappyframe == true then
		PetFrameHappiness.Show = function() end
		PetFrameHappiness:Hide()
	else
		if UnitExists("pet") then
			PetFrameHappiness.Show = nil
		end
		PetFrame:RegisterEvent("UNIT_HAPPINESS")
		PetFrame:RegisterEvent("PET_UI_UPDATE")
	end

	if db.petunitframe == true then
		PetFrame:UnregisterAllEvents()
		PetFrame.Show = function() end
		PetFrame:Hide()
	else
		if UnitExists("pet") then
			PetFrame.Show = nil
			PetFrame:Show()
		end
		PetFrame:RegisterEvent("UNIT_PET")
		PetFrame:RegisterEvent("UNIT_COMBAT")
		PetFrame:RegisterEvent("UNIT_AURA")
		PetFrame:RegisterEvent("PET_ATTACK_START")
		PetFrame:RegisterEvent("PET_ATTACK_STOP")
		PetFrame:RegisterEvent("UNIT_HAPPINESS")
		PetFrame:RegisterEvent("PET_UI_UPDATE")
		PetFrame:RegisterEvent("PET_RENAMEABLE")
	end
end